@@ -421,9 +421,8 @@ class Indexer(object):
             else:
                 aptprogress = None
 
-            # memonly=True: force apt to not write a pkgcache.bin
             apt_pkg.init_config()
-            self.apt_cache = apt.Cache(memonly=True, progress=aptprogress)
+            self.apt_cache = apt.Cache(progress=aptprogress)
         return self.apt_cache
 
     def lock(self):
